/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2013 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.data;

import java.util.Date;
import java.util.regex.Matcher;
import com.openexchange.Definitions;
import com.openexchange.git.MergeException;

/**
 * {@link DebianChangeLogEntry}
 *
 * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
 */
public final class DebianChangeLogEntry extends SpecChangeLogEntry {

    private final String packageName;
    private final int major, minor, patch, revision;
    private final String release;

    public DebianChangeLogEntry(String packageName, String version, String release, String comment, String author, Date date) throws MergeException {
        super(date, author, comment);
        this.packageName = packageName;
        Matcher matcher = Definitions.VERSION_AND_REVISION_PATTERN.matcher(version);
        if (matcher.matches()) {
            String tmp = matcher.group(1);
            try {
                major = Integer.parseInt(tmp);
            } catch (NumberFormatException e) {
                throw new MergeException("Can not parse number \"" + tmp + "\".", e);
            }
            tmp = matcher.group(2);
            try {
                minor = Integer.parseInt(tmp);
            } catch (NumberFormatException e) {
                throw new MergeException("Can not parse number \"" + tmp + "\".", e);
            }
            tmp = matcher.group(3);
            try {
                patch = Integer.parseInt(tmp);
            } catch (NumberFormatException e) {
                throw new MergeException("Can not parse number \"" + tmp + "\".", e);
            }
            tmp = matcher.group(4);
            try {
                revision = Integer.parseInt(tmp);
            } catch (NumberFormatException e) {
                throw new MergeException("Can not parse number \"" + tmp + "\".", e);
            }
        } else {
            throw new MergeException("Can not parse version string \"" + version + "\".");
        }
        this.release = release;
    }

    public int getMajor() {
        return major;
    }

    public int getMinor() {
        return minor;
    }

    public int getPatch() {
        return patch;
    }

    public int getRevision() {
        return revision;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(packageName);
        sb.append(" (");
        sb.append(major);
        sb.append('.');
        sb.append(minor);
        sb.append('.');
        sb.append(patch);
        sb.append('-');
        sb.append(revision);
        sb.append(") ");
        sb.append(release);
        sb.append("\n\n  * ");
        sb.append(getComment());
        sb.append("\n\n -- ");
        sb.append(getAuthor());
        sb.append("  ");
        Definitions.DEBIAN_DF.getCalendar().setTime(getDate());
        sb.append(Definitions.DEBIAN_DF.format(getDate()));
        sb.append('\n');
        return sb.toString();
    }
}
